from . import str_similarity
# from .str import *